@@ -3,7 +3,7 @@ import os
 from vellum.api_resources.search import Search
 from vellum.api_resources import Generate
 from vellum.api_resources.completion_actuals import SubmitCompletionActuals
-from vellum.api_resources.types import CompletionActual, GenerateRequest, SearchOptions
+from vellum.api_resources.types import CompletionActual, GenerateRequest, SearchOptions, SearchWeights
 
 api_key = os.environ.get("VELLUM_API_KEY")
 
@@ -13,6 +13,7 @@ __all__ = [
     "GenerateRequest",
     "Search",
     "SearchOptions",
+    "SearchWeights",
     "SubmitCompletionActuals",
     "api_key",
 ]
